@@ -11,11 +11,15 @@ type RollbackTestSuite struct {
 	suite.Suite
 }
 
-func (ts *RollbackTestSuite) TestImplementsAction() {
-	ts.Require().Implements((*action.Action)(nil), &action.Rollback{})
-}
-
 func TestRollbackTestSuite(t *testing.T) {
 	t.Parallel()
 	suite.Run(t, new(RollbackTestSuite))
 }
+
+func (ts *RollbackTestSuite) TestCmd() {
+	s := &action.Rollback{}
+	cmd := s.Cmd()
+
+	ts.Require().NotNil(cmd)
+	ts.Require().NotEmpty(cmd.Name)
+}
