@@ -14,6 +14,8 @@ import (
 
 type StatusTestSuite struct {
 	suite.Suite
+
+	ctx context.Context
 }
 
 //nolint:paralleltest // can't parallel because of setenv
@@ -22,6 +24,10 @@ func TestStatusTestSuite(t *testing.T) {
 	suite.Run(t, new(StatusTestSuite))
 }
 
+func (ts *StatusTestSuite) SetupTest() {
+	ts.ctx = tests.GetContext(ts.T())
+}
+
 func (ts *StatusTestSuite) TestCmd() {
 	s := &Status{}
 	cmd := s.Cmd()
@@ -45,11 +51,11 @@ func (ts *StatusTestSuite) TestRun() {
 	value := strings.ToLower(strings.ReplaceAll(ts.T().Name(), "/", ""))
 	ts.T().Setenv("NAMESPACE", value)
 
-	ts.Require().NoError(r.Run(context.Background()))
+	ts.Require().NoError(r.Run(ts.ctx))
 
 	s := &Status{
 		build: r,
 	}
 
-	ts.Require().NoError(s.Run(context.Background()))
+	ts.Require().NoError(s.Run(ts.ctx))
 }
