@@ -6,7 +6,6 @@ import (
 	"testing"
 
 	"github.com/helmwave/helmwave/pkg/plan"
-	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/suite"
 	"helm.sh/helm/v3/pkg/chart"
 	helmRelease "helm.sh/helm/v3/pkg/release"
@@ -20,7 +19,7 @@ func (s *ListTestSuite) TestList() {
 	tmpDir := s.T().TempDir()
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 
-	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease := plan.NewMockReleaseConfig(s.T())
 	r := &helmRelease.Release{
 		Info: &helmRelease.Info{},
 		Chart: &chart.Chart{
@@ -42,9 +41,8 @@ func (s *ListTestSuite) TestListError() {
 	tmpDir := s.T().TempDir()
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 
-	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease := plan.NewMockReleaseConfig(s.T())
 	mockedRelease.On("List").Return(&helmRelease.Release{}, errors.New(s.T().Name()))
-	mockedRelease.On("Logger").Return(log.WithField("test", s.T().Name()))
 
 	p.SetReleases(mockedRelease)
 
