@@ -9,7 +9,6 @@ import (
 	"github.com/helmwave/helmwave/pkg/kubedog"
 	"github.com/helmwave/helmwave/pkg/plan"
 	"github.com/helmwave/helmwave/tests"
-	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/suite"
 )
 
@@ -32,9 +31,8 @@ func (ts *RollbackTestSuite) TestRollback() {
 	tmpDir := ts.T().TempDir()
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 
-	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease := plan.NewMockReleaseConfig(ts.T())
 	mockedRelease.On("Rollback").Return(nil)
-	mockedRelease.On("Logger").Return(log.WithField("test", ts.T().Name()))
 
 	p.SetReleases(mockedRelease)
 
@@ -48,10 +46,9 @@ func (ts *RollbackTestSuite) TestRollbackError() {
 	tmpDir := ts.T().TempDir()
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 
-	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease := plan.NewMockReleaseConfig(ts.T())
 	e := errors.New(ts.T().Name())
 	mockedRelease.On("Rollback").Return(e)
-	mockedRelease.On("Logger").Return(log.WithField("test", ts.T().Name()))
 
 	p.SetReleases(mockedRelease)
 
