@@ -2,11 +2,6 @@ package repo
 
 import "slices"
 
-// Equal checks repo configs to have equal names.
-func (rep *config) Equal(a Config) bool {
-	return rep.Name() == a.Name()
-}
-
 // IndexOfName searches repository in slice of repositories by name. Returns offset.
 func IndexOfName(a []Config, name string) (int, bool) {
 	i := slices.IndexFunc(a, func(r Config) bool {
