@@ -2,10 +2,14 @@ package template
 
 import (
 	"bytes"
+	"context"
 	"fmt"
+	"io"
+	"maps"
 	"text/template"
 
 	"github.com/Masterminds/sprig/v3"
+	"github.com/helmwave/helmwave/pkg/parallel"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -14,12 +18,12 @@ const (
 )
 
 var (
-	sprigAliases = map[string]string{ //nolint:gochecknoglobals // can't make these const
+	sprigAliases = map[string]string{
 		"get":    "sprigGet",
 		"hasKey": "sprigHasKey",
 	}
 
-	customFuncs = map[string]any{ //nolint:gochecknoglobals // can't make these const
+	customFuncs = map[string]any{
 		"toYaml":         ToYaml,
 		"fromYaml":       FromYaml,
 		"exec":           Exec,
@@ -33,24 +37,44 @@ var (
 )
 
 type sprigTemplater struct {
+	additionalFuncs               map[string]any
 	delimiterLeft, delimiterRight string
+	additionalOutputs             []io.Writer
 }
 
 func (t sprigTemplater) Name() string {
 	return TemplaterSprig
 }
 
-func (t sprigTemplater) Render(src string, data any) ([]byte, error) {
+func (t sprigTemplater) Render(ctx context.Context, src string, data any) ([]byte, error) {
 	funcs := t.funcMap()
+	if t.additionalFuncs != nil {
+		maps.Copy(funcs, t.additionalFuncs)
+	}
+
 	tpl, err := template.New("tpl").Delims(t.delimiterLeft, t.delimiterRight).Funcs(funcs).Parse(src)
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse template: %w", err)
 	}
 
 	var buf bytes.Buffer
-	err = tpl.Execute(&buf, data)
+	writers := []io.Writer{&buf}
+	if t.additionalOutputs != nil {
+		writers = append(writers, t.additionalOutputs...)
+	}
+	w := io.MultiWriter(writers...)
+
+	wg := parallel.NewWaitGroup()
+	wg.Add(1)
+
+	go func() {
+		defer wg.Done()
+		wg.ErrChan() <- tpl.Execute(w, data)
+	}()
+
+	err = wg.WaitWithContext(ctx)
 	if err != nil {
-		return nil, fmt.Errorf("failed to render template: %w", err)
+		return nil, err
 	}
 
 	return buf.Bytes(), nil
@@ -72,12 +96,25 @@ func (t sprigTemplater) funcMap() template.FuncMap {
 }
 
 func addToMap(dst, src template.FuncMap) {
-	for k, v := range src {
-		dst[k] = v
-	}
+	maps.Copy(dst, src)
 }
 
 func (t *sprigTemplater) Delims(left, right string) {
 	t.delimiterLeft = left
 	t.delimiterRight = right
 }
+
+func (t *sprigTemplater) AddOutput(w io.Writer) {
+	if t.additionalOutputs == nil {
+		t.additionalOutputs = []io.Writer{}
+	}
+	t.additionalOutputs = append(t.additionalOutputs, w)
+}
+
+func (t *sprigTemplater) AddFunc(name string, f any) {
+	if t.additionalFuncs == nil {
+		t.additionalFuncs = map[string]any{}
+	}
+
+	t.additionalFuncs[name] = f
+}
